<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "iteratetestdata.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gfn="http://www.greenhatsoftware.com/Functions.xsl"
	exclude-result-prefixes="gfn">

	<!-- externalisations -->
	<xsl:variable name="iteratetestdata.iteration">
		<xsl:text>&iteratetestdata.iteration;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.iterationNumber">
		<xsl:text>&iteratetestdata.iterationNumber;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.iterationNumberWithIndex">
		<xsl:text>&iteratetestdata.iterationNumberWithIndex;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.testDataSet">
		<xsl:text>&iteratetestdata.testDataSet;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.name">
		<xsl:text>&iteratetestdata.name;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.usageSummary">
		<xsl:text>&iteratetestdata.usageSummary;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.dataRow">
		<xsl:text>&iteratetestdata.dataRow;</xsl:text>
	</xsl:variable>
	<xsl:variable name="iteratetestdata.multipleInstanceIterationText">
		<xsl:text>&iteratetestdata.multipleInstanceIterationText;</xsl:text>
	</xsl:variable>

	<xsl:variable name="ITERATION" select="'iteration'" />
	<xsl:variable name="ITERATION_NUMBER" select="'iterationNumber'" />
	<xsl:variable name="ITERATION_COUNT" select="'iterationCount'" />

	<xsl:template match="iteration" mode="summary">
		<xsl:call-template name="processSummaryRow">
			<xsl:with-param name="name"
				select="gfn:formatString($iteratetestdata.iterationNumberWithIndex,string-join(ancestor-or-self::iteration/@iterationNumber,'.'))" />
			<xsl:with-param name="label" select="false()" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generateIterationName">
		<xsl:variable name="testID">
			<xsl:call-template name="getTestID" />
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="@id!=$testID">
				<xsl:variable name="id">
					<xsl:value-of select="@id" />
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="count(parent::*[name()=$SERIAL_TASK]) &gt; 0">
						<xsl:value-of select="parent::*/@id" />
						<xsl:value-of select="string(':')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="/descendant-or-self::*[@childTaskId=$id][1]">
							<xsl:value-of select="@id" />
							<xsl:value-of select="string(':')" />
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		<xsl:value-of
			select="gfn:formatString($iteratetestdata.iterationNumberWithIndex,string-join(ancestor-or-self::iteration/@iterationNumber,'.'))" />
	</xsl:template>

	<xsl:template name="getIterationID">
		<xsl:value-of
			select="string-join(ancestor-or-self::iteration/@iterationNumber,'.')" />
	</xsl:template>

	<xsl:template name="getIterationCount">
		<xsl:param name="id" />
		<xsl:variable name="testId">
			<xsl:choose>
				<xsl:when test="string-length($id)!=0">
					<xsl:value-of select="$id" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="getTestID" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:for-each select="/Test/summary[@id=$testId]">
			<xsl:value-of select="gfn:notBlank(@*[name()=$ITERATION_COUNT])" />
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="iteration">
		<xsl:variable name="name">
			<xsl:variable name="id">
				<xsl:call-template name="generateIterationName" />
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$id=string('Iteration#Multiple Instance')">
					<xsl:variable name="instCount"
						select="/*/runProfileProperties/@performanceInstances" />
					<xsl:variable name="testId">
						<xsl:call-template name="getTestID" />
					</xsl:variable>

					<xsl:value-of
						select="gfn:formatString($iteratetestdata.multipleInstanceIterationText,$instCount,$testId)" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$id" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:call-template name="addSectionHeader">
			<xsl:with-param name="header" select="$name" />
		</xsl:call-template>
		<xsl:call-template name="createSummaryTable" />
		<xsl:call-template name="processTagDataStore">
			<xsl:with-param name="elementName" select="$TAG_VALUES" />
			<xsl:with-param name="tableName" select="$TAG_VALUES_OUTPUT" />
		</xsl:call-template>
		<xsl:apply-templates select="*" />
	</xsl:template>

	<xsl:template name="reportIterationNumber">
		<xsl:param name="withTitle" select="true()" />
		<xsl:call-template name="copyAttribute">
			<xsl:with-param name="attribute" select="$ITERATION_NUMBER" />
			<xsl:with-param name="outputAttribute"
				select="$iteratetestdata.iterationNumber" />
			<xsl:with-param name="withTitle" select="$withTitle" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="processTestDataSet">
		<xsl:if
			test="//runProfileProperties[ string-length( @testDataTestDataSetPath ) &gt;0 ]">
			<xsl:call-template name="addSectionHeader">
				<xsl:with-param name="header" select="$iteratetestdata.testDataSet" />
			</xsl:call-template>
			<table>
				<tr>
					<th>
						<xsl:value-of select="$iteratetestdata.name" />
					</th>
					<td>
						<xsl:value-of select="//runProfileProperties/@testDataTestDataSetPath" />
					</td>
				</tr>
			</table>
			<xsl:call-template name="addSectionHeader">
				<xsl:with-param name="header" select="$iteratetestdata.usageSummary" />
			</xsl:call-template>
			<table>
				<th>
					<xsl:value-of select="$iteratetestdata.dataRow" />
				</th>
				<th>
					<xsl:value-of select="$iteratetestdata.iteration" />
				</th>
				<xsl:call-template name="processTestData" />
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="processTestData">
		<xsl:param name="count" select="number(0)" />
		<xsl:variable name="usedRow">
			<xsl:if
				test="count(//iteration[((number(@iterationNumber) -1) mod number(//runProfileProperties/@testDataSetRows))=$count ])!=0">
				<xsl:value-of select="'used'" />
			</xsl:if>
		</xsl:variable>
		<xsl:if
			test="$usedRow='used' and number($count) &lt; number(//runProfileProperties/@testDataSetRows)">
			<tr>
				<td>
					<xsl:value-of select="number($count)+1" />
				</td>
				<td>
					<xsl:for-each
						select="//iteration[((number(@iterationNumber) -1) mod number(//runProfileProperties/@testDataSetRows))=$count ]">
						<xsl:variable name="displayName"
							select="gfn:formatString($iteratetestdata.iterationNumberWithIndex,@iterationNumber)" />
						<a>
							<xsl:attribute name="href" select="concat('#',generate-id())" />
							<xsl:value-of select="$displayName" />
						</a>
						<xsl:variable name="counter"
							select="count(preceding-sibling::*[name()='iteration' and ( ( (number(@iterationNumber)-1) mod number(//runProfileProperties/@testDataSetRows) )=$count)])" />
						<xsl:variable name="total"
							select=" count(//iteration[((number(@iterationNumber) -1) mod number(//runProfileProperties/@testDataSetRows))=$count ])" />

						<xsl:if test="number($counter)+1 &lt; number($total)">
							<xsl:value-of select="string('--')" />
						</xsl:if>
					</xsl:for-each>
				</td>
			</tr>
			<xsl:call-template name="processTestData">
				<xsl:with-param name="count" select="number($count)+1" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>