--
-- Migrate database from schema version 1.9.17 to 1.9.18
--
DECLARE 
  required_version VARCHAR2(100);
  current_version VARCHAR2(100);
BEGIN
  SELECT '1.9.17' INTO required_version FROM dual;
  SELECT value INTO current_version FROM db_details 
    WHERE property='schema.version.number' 
    AND ctime = (
      SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number' 
    );
    
   IF current_version != required_version THEN
     RAISE_APPLICATION_ERROR( -20001, 
                             'Incorrect schema version: ' || current_version  ||
                             ', expected: ' || required_version );
                             
   ELSE
-- 
-- Update Script here
--

EXECUTE IMMEDIATE 'drop table sonic_broker_ts';
EXECUTE IMMEDIATE 'drop table sonic_broker_mrv';

EXECUTE IMMEDIATE
  'CREATE TABLE "SONIC_BROKER_MRV"(
      "ID"                  NUMBER(19, 0)    NOT NULL,
      "SONIC_AGENT_MRV_ID"  NUMBER(19, 0)    NOT NULL,
      "BROKER"              VARCHAR2(256)    NOT NULL,
      "TIME"                NUMBER(20, 0)    NOT NULL,
      CONSTRAINT "SONIC_BROKER_MRV_PK" PRIMARY KEY ("ID"),
        UNIQUE ("SONIC_AGENT_MRV_ID", "BROKER"), 
      FOREIGN KEY ("SONIC_AGENT_MRV_ID")
      REFERENCES "SONIC_AGENT_MRV"("ID")
)';

EXECUTE IMMEDIATE
  'CREATE TABLE "SONIC_BROKER_TS"(
      "IDX"                  NUMBER(19, 0)    NOT NULL,
      "SONIC_BROKER_MRV_ID"  NUMBER(19, 0)    NOT NULL,
      "EXECUTION_ID"         NUMBER(19, 0),
      "TIME"                 NUMBER(20, 0)    NOT NULL,
      "APPMSGRECEIVED"       NUMBER(10, 0),
      "APPMSGDELIVERED"      NUMBER(10, 0),
      "BYTESRECEIVED"        NUMBER(10, 0),
      "BYTESDELIVERED"       NUMBER(10, 0),
      "CONNSCOUNT"           NUMBER(10, 0),
      "CONNSREJECT"          NUMBER(10, 0),
      "TOPICSTORESIZE"       NUMBER(10, 0),
    FOREIGN KEY ("EXECUTION_ID")
    REFERENCES "EXECUTION"("ID") ON DELETE CASCADE,
    FOREIGN KEY ("SONIC_BROKER_MRV_ID")
    REFERENCES "SONIC_BROKER_MRV"("ID")
)';

INSERT INTO db_details VALUES
   ( (SELECT sysdate FROM dual), 'schema.version.number','1.9.18');

commit;

   END IF; -- version check
END;
/