--
-- Migrate database from schema version 1.9.24 to 1.9.24.a
--
DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.24';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--

CREATE TEMPORARY TABLE
    Temp_probe_config
(
	`execution_id`  BIGINT      NOT NULL,
    `config`        LONGTEXT
) ENGINE=INNODB
;

INSERT INTO 
    Temp_probe_config
(
    execution_id, config
)
SELECT 
    execution_id, config
FROM
    probe_config
;

DROP TABLE probe_config
;

CREATE TABLE `probe_config`(
    `execution_id`  BIGINT      NOT NULL,
    `config`        LONGTEXT,
    PRIMARY KEY (`execution_id`), 
    CONSTRAINT `probe_config_ibfk_2` FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

INSERT INTO 
    probe_config
(
    execution_id, config
)
SELECT 
    execution_id, config
FROM
    Temp_probe_config
;

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.24.a');

commit;

  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;

