
--
-- Migrate database from schema version 1.9.24.e to 1.9.24.f
--

-- Check that 'e' is the most recent schema upgrade that has been applied
declare @dbVersion nvarchar(20)
declare @requiredVersion nvarchar(20)

set @requiredVersion = '1.9.24.e'
select @dbVersion = IsNull([value], '<unknown>') from db_details where property='schema.version.number' order by ctime desc
	
IF @dbVersion <> @requiredVersion
BEGIN
	PRINT 'This script can only be run against version ' + @requiredVersion + ' of the Results Database.'
	PRINT 'This results database is at version ' + @dbVersion
	PRINT 'You must run previous upgrade scripts in order to upgrade the Results Database to version 1.9.24.e before running this script'
	PRINT 'No changes have been made to the database.'	
	RAISERROR ('Schema is not the correct version for this script',16,-1)        
	set nocount on
    set noexec on
	RETURN
END


-- Before we can change types on columns we need to remove all constraints (PK and UNIQUES) referencing
-- those columns. These will be put back on later, although some of them in slightly different forms
-- where the new index would be too large

IF NOT EXISTS (SELECT  * FROM DB_DETAILS WHERE PROPERTY='schema.version.number' and VALUE = '1.9.24.f')
BEGIN
PRINT 'INCREMENTING SCHEMA VERSION'

BEGIN TRANSACTION
INSERT INTO db_details VALUES
 (GETDATE(), 'schema.version.number', '1.9.24.f')
COMMIT TRANSACTION
END

GO

set nocount off
set noexec off
	
